%global major_version 73
%bcond_without dotests
Name:      icu
Version:   73.2
Release:   1
Summary:   International Components for Unicode

License:   Unicode-DFS-2016 AND BSD-2-Clause AND BSD-3-Clause AND LicenseRef-Fedora-Public-Domain
URL:       https://site.icu-project.org/
Source0:   https://github.com/unicode-org/icu/releases/download/release-73-2/icu4c-73_2-src.tgz
Patch0:	   icuinfo-man.patch
Patch1:	   icu-73.2-archive_versioned_so.patch

BuildRequires: gcc
BuildRequires: gcc-c++
BuildRequires: autoconf, python3
BuildRequires: make
%if %{toolchain} == "gcc"
Requires:       libgcc >= 10.3.0
Requires:	libstdc++ >= 10.3.0
%endif
Requires: lib%{name} = %{version}-%{release}


%description
Tools and utilities for developing with icu.

%package -n lib%{name}
Summary: International Components for Unicode - libraries
%if %{toolchain} == "gcc"
Requires:       libgcc >= 10.3.0
Requires:       libstdc++ >= 10.3.0
%endif

%description -n lib%{name}
The International Components for Unicode (ICU) libraries provide
robust and full-featured Unicode services on a wide variety of
platforms. ICU supports the most current version of the Unicode
standard, and they provide support for supplementary Unicode
characters (needed for GB 18030 repertoire support).
As computing environments become more heterogeneous, software
portability becomes more important. ICU lets you produce the same
results across all the various platforms you support, without
sacrificing performance. It offers great flexibility to extend and
customize the supplied services.

%package  -n lib%{name}-devel
Summary:  Development files for International Components for Unicode
Requires: lib%{name} = %{version}-%{release}
Requires: pkgconfig >= 0.29.2
%if %{toolchain} == "gcc"
Requires:       libgcc >= 10.3.0
Requires:       libstdc++ >= 10.3.0
%endif

%description -n lib%{name}-devel
Includes and definitions for developing with icu.


%prep
%setup -q -n %{name}
%patch0 -p1
%patch1 -p1
rm -rf   /tmp/%{name}-%{version}-32bit
cp -pr . /tmp/%{name}-%{version}-32bit
rm -fr *
mv       /tmp/%{name}-%{version}-32bit 32bit
cp -pr 32bit 64bit

%build
# build on 64bit mode
export OBJECT_MODE=64
cd 64bit/source
export CC="/opt/freeware/bin/gcc -O2 -maix64 -pthread -fPIC"
export CXX="/opt/freeware/bin/g++ -O2 -maix64 -pthread -fPIC"
export LDFLAGS="-L/opt/freeware/lib64 -L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib/pthread/ppc64:/opt/freeware/lib64:/opt/freeware/lib:/usr/lib:/lib /opt/freeware/lib/pthread/ppc64/libstdc++.a"
./configure --prefix=%{_prefix} \
            --libdir=%{_libdir} \
	    --mandir=%{_mandir}

gmake -j8

# build on 32bit mode
export OBJECT_MODE=32
cd ../../32bit/source
export CC="/opt/freeware/bin/gcc -O2 -D_LARGE_FILES -maix32 -pthread -fPIC"
export CXX="/opt/freeware/bin/g++ -O2 -D_LARGE_FILES -maix32 -pthread -fPIC"
export LDFLAGS="-L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib/pthread:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000 /opt/freeware/lib/pthread/libstdc++.a"
./configure --prefix=%{_prefix} \
	    --libdir=%{_libdir} \
	    --mandir=%{_mandir}

gmake -j8

%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}
# install on 32bit mode
export OBJECT_MODE=32
cd 32bit
gmake install DESTDIR=${RPM_BUILD_ROOT} -C source
(
 cd ${RPM_BUILD_ROOT}%{_libdir}
 for lib in libicudata libicui18n libicuio libicutest libicutu libicuuc; do
  ar -X32 -x ${lib}%{version}.a
 done
)

# install on 64bit mode
export OBJECT_MODE=64
cd ../64bit
gmake install DESTDIR=${RPM_BUILD_ROOT} -C source

#Archiving 32bit shared objects
(
 cd ${RPM_BUILD_ROOT}%{_libdir}
 for lib in libicudata libicui18n libicuio libicutest libicutu libicuuc
 do
  ar -X32 -q ${lib}73.2.a ${lib}%{major_version}.so
 done
)


%if %{with dotests}
%check
cd 64bit
gmake -C source check||true
cd ../32bit
gmake -C source check||true
%endif


%files
%defattr(-,root,system)
%license 32bit/license.html
%exclude %{_datadir}/%{name}/*/LICENSE
%{_bindir}/derb*
%{_bindir}/genbrk*
%{_bindir}/gencfu*
%{_bindir}/gencnval*
%{_bindir}/gendict*
%{_bindir}/genrb*
%{_bindir}/icuexportdata*
%{_bindir}/makeconv*
%{_bindir}/pkgdata*
%{_bindir}/uconv*
%{_sbindir}/*
%{_mandir}/man1/derb.1*
%{_mandir}/man1/genbrk.1*
%{_mandir}/man1/gencfu.1*
%{_mandir}/man1/gencnval.1*
%{_mandir}/man1/gendict.1*
%{_mandir}/man1/genrb.1*
%{_mandir}/man1/icuexportdata.1*
%{_mandir}/man1/makeconv.1*
%{_mandir}/man1/pkgdata.1*
%{_mandir}/man1/uconv.1*
%{_mandir}/man8/*.8*

%files -n lib%{name}
%defattr(-,root,system)
%license 32bit/LICENSE
%doc 32bit/readme.html
%{_libdir}/*%{major_version}*.a

%files -n lib%{name}-devel
%defattr(-,root,system)
%license 32bit/LICENSE
%doc 32bit/source/samples/
%{_bindir}/%{name}-config*
%{_bindir}/icuinfo*
%{_mandir}/man1/%{name}-config.1*
%{_mandir}/man1/icuinfo.1*
%{_includedir}/unicode
%{_libdir}/pkgconfig/*.pc
%{_libdir}/%{name}
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/%{version}
%{_datadir}/%{name}/%{version}/install-sh
%{_datadir}/%{name}/%{version}/mkinstalldirs
%{_datadir}/%{name}/%{version}/config


%changelog
* Tue Feb 13 2024 Reshma V Kumar <reskumar@in.ibm.com> - 73.2-1
- Initial port to AIX Toolbox
